@@ -503,6 +503,8 @@ const char *cap_mode_name(cap_mode_t flavor) {
 	return "PURE1E";
     case CAP_MODE_UNCERTAIN:
 	return "UNCERTAIN";
+    case CAP_MODE_HYBRID:
+	return "HYBRID";
     default:
 	return "UNKNOWN";
     }
@@ -520,6 +522,7 @@ char *cap_iab_to_text(cap_iab_t iab)
     int first = 1;
 
     if (good_cap_iab_t(iab)) {
+	_cap_mu_lock(&iab->mutex);
 	for (c = 0; c < cmb; c++) {
 	    int keep = 0;
 	    int o = c >> 5;
@@ -553,6 +556,7 @@ char *cap_iab_to_text(cap_iab_t iab)
 		first = 0;
 	    }
 	}
+	_cap_mu_unlock(&iab->mutex);
     }
     *p = '\0';
     return _libcap_strdup(buf);
@@ -669,7 +673,7 @@ static __u32 _parse_vec_string(__u32 *vals, const char *c, int invert)
 
 /*
  * libcap believes this is the root of the mounted "/proc"
- * filesystem
+ * filesystem. (NULL == "/proc".)
  */
 static char *_cap_proc_dir;
 
@@ -695,6 +699,8 @@ __attribute__((destructor (300))) static void _cleanup_libcap(void)
  * memory for storing the replacement root, and it is this memory that
  * is returned. So, when changing the value, the caller should
  * cap_free(the-return-value) when done with it.
+ *
+ * A return value of NULL implies the default is in effect "/proc".
  */
 char *cap_proc_root(const char *root)
 {
@@ -717,8 +723,12 @@ cap_iab_t cap_iab_get_pid(pid_t pid)
     char *path;
     FILE *file;
     char line[PROC_LINE_MAX];
+    const char *proc_root = _cap_proc_dir;
 
-    if (asprintf(&path, "%s/%d/status", _cap_proc_dir, pid) <= 0) {
+    if (proc_root == NULL) {
+	proc_root = "/proc";
+    }
+    if (asprintf(&path, "%s/%d/status", proc_root, pid) <= 0) {
 	return NULL;
     }
     file = fopen(path, "r");
